@@ -109,6 +109,7 @@ types: list[str] = [
     "AWS::CUR::ReportDefinition",
     "AWS::Cassandra::Keyspace",
     "AWS::Cassandra::Table",
+    "AWS::Cassandra::Type",
     "AWS::CertificateManager::Account",
     "AWS::CertificateManager::Certificate",
     "AWS::Cloud9::EnvironmentEC2",
@@ -297,6 +298,7 @@ types: list[str] = [
     "AWS::EMR::SecurityConfiguration",
     "AWS::EMR::Step",
     "AWS::EMR::Studio",
+    "AWS::EMRContainers::VirtualCluster",
     "AWS::EMRServerless::Application",
     "AWS::ElastiCache::CacheCluster",
     "AWS::ElastiCache::GlobalReplicationGroup",
@@ -428,6 +430,7 @@ types: list[str] = [
     "AWS::IoT::TopicRuleDestination",
     "AWS::KMS::Alias",
     "AWS::KMS::Key",
+    "AWS::KMS::ReplicaKey",
     "AWS::Kinesis::ResourcePolicy",
     "AWS::Kinesis::Stream",
     "AWS::Kinesis::StreamConsumer",
@@ -699,6 +702,7 @@ cached: list[str] = [
     "aws-apigateway-documentationversion.json",
     "aws-apigateway-domainname.json",
     "aws-apigateway-domainnameaccessassociation.json",
+    "aws-apigateway-domainnamev2.json",
     "aws-apigateway-gatewayresponse.json",
     "aws-apigateway-method.json",
     "aws-apigateway-model.json",
@@ -723,7 +727,6 @@ cached: list[str] = [
     "aws-apigatewayv2-vpclink.json",
     "aws-appconfig-application.json",
     "aws-appconfig-configurationprofile.json",
-    "aws-appconfig-deployment.json",
     "aws-appconfig-deploymentstrategy.json",
     "aws-appconfig-environment.json",
     "aws-appconfig-extension.json",
@@ -771,6 +774,7 @@ cached: list[str] = [
     "aws-budgets-budgetsaction.json",
     "aws-cassandra-keyspace.json",
     "aws-cassandra-table.json",
+    "aws-cassandra-type.json",
     "aws-ce-anomalymonitor.json",
     "aws-ce-anomalysubscription.json",
     "aws-ce-costcategory.json",
@@ -793,6 +797,7 @@ cached: list[str] = [
     "aws-cloudfront-keygroup.json",
     "aws-cloudfront-publickey.json",
     "aws-cloudfront-responseheaderspolicy.json",
+    "aws-cloudtrail-trail.json",
     "aws-cloudwatch-alarm.json",
     "aws-cloudwatch-anomalydetector.json",
     "aws-cloudwatch-compositealarm.json",
@@ -848,7 +853,7 @@ cached: list[str] = [
     "aws-docdb-dbinstance.json",
     "aws-docdb-dbsubnetgroup.json",
     "aws-docdb-eventsubscription.json",
-    "aws-dynamodb-globaltable.json",
+    "aws-dynamodb-table.json",
     "aws-ec2-capacityreservation.json",
     "aws-ec2-capacityreservationfleet.json",
     "aws-ec2-dhcpoptions.json",
@@ -874,6 +879,7 @@ cached: list[str] = [
     "aws-ec2-natgateway.json",
     "aws-ec2-networkacl.json",
     "aws-ec2-networkaclentry.json",
+    "aws-ec2-networkinterface.json",
     "aws-ec2-networkinterfacepermission.json",
     "aws-ec2-placementgroup.json",
     "aws-ec2-prefixlist.json",
@@ -927,6 +933,7 @@ cached: list[str] = [
     "aws-ecs-clustercapacityproviderassociations.json",
     "aws-ecs-primarytaskset.json",
     "aws-ecs-service.json",
+    "aws-ecs-taskdefinition.json",
     "aws-ecs-taskset.json",
     "aws-efs-accesspoint.json",
     "aws-efs-filesystem.json",
@@ -938,10 +945,12 @@ cached: list[str] = [
     "aws-eks-nodegroup.json",
     "aws-eks-podidentityassociation.json",
     "aws-elasticache-cachecluster.json",
+    "aws-elasticache-globalreplicationgroup.json",
     "aws-elasticache-parametergroup.json",
     "aws-elasticache-replicationgroup.json",
     "aws-elasticache-securitygroup.json",
     "aws-elasticache-securitygroupingress.json",
+    "aws-elasticache-serverlesscache.json",
     "aws-elasticache-subnetgroup.json",
     "aws-elasticache-user.json",
     "aws-elasticbeanstalk-application.json",
@@ -963,6 +972,8 @@ cached: list[str] = [
     "aws-emr-securityconfiguration.json",
     "aws-emr-step.json",
     "aws-emr-studio.json",
+    "aws-emrcontainers-virtualcluster.json",
+    "aws-emrserverless-application.json",
     "aws-events-archive.json",
     "aws-events-eventbus.json",
     "aws-events-eventbuspolicy.json",
@@ -1064,6 +1075,7 @@ cached: list[str] = [
     "aws-iot-topicrule.json",
     "aws-iot-topicruledestination.json",
     "aws-kinesis-resourcepolicy.json",
+    "aws-kinesis-stream.json",
     "aws-kinesis-streamconsumer.json",
     "aws-kinesisanalytics-applicationoutput.json",
     "aws-kinesisanalyticsv2-application.json",
@@ -1071,6 +1083,7 @@ cached: list[str] = [
     "aws-kinesisfirehose-deliverystream.json",
     "aws-kms-alias.json",
     "aws-kms-key.json",
+    "aws-kms-replicakey.json",
     "aws-lakeformation-datacellsfilter.json",
     "aws-lakeformation-datalakesettings.json",
     "aws-lakeformation-permissions.json",
@@ -1089,11 +1102,14 @@ cached: list[str] = [
     "aws-logs-deliverydestination.json",
     "aws-logs-deliverysource.json",
     "aws-logs-destination.json",
+    "aws-logs-loggroup.json",
     "aws-logs-logstream.json",
+    "aws-logs-metricfilter.json",
+    "aws-logs-querydefinition.json",
     "aws-logs-resourcepolicy.json",
+    "aws-logs-subscriptionfilter.json",
     "aws-mediaconvert-jobtemplate.json",
     "aws-mediaconvert-preset.json",
-    "aws-mediaconvert-queue.json",
     "aws-msk-batchscramsecret.json",
     "aws-msk-cluster.json",
     "aws-msk-clusterpolicy.json",
@@ -1109,6 +1125,7 @@ cached: list[str] = [
     "aws-networkfirewall-tlsinspectionconfiguration.json",
     "aws-oam-link.json",
     "aws-oam-sink.json",
+    "aws-opensearchservice-domain.json",
     "aws-opsworks-app.json",
     "aws-opsworks-elasticloadbalancerattachment.json",
     "aws-opsworks-instance.json",
@@ -1119,9 +1136,11 @@ cached: list[str] = [
     "aws-organizations-account.json",
     "aws-organizations-organization.json",
     "aws-organizations-organizationalunit.json",
+    "aws-organizations-policy.json",
     "aws-organizations-resourcepolicy.json",
     "aws-pipes-pipe.json",
     "aws-ram-permission.json",
+    "aws-ram-resourceshare.json",
     "aws-rbin-rule.json",
     "aws-rds-dbcluster.json",
     "aws-rds-dbclusterparametergroup.json",
@@ -1150,13 +1169,13 @@ cached: list[str] = [
     "aws-redshiftserverless-namespace.json",
     "aws-resourcegroups-group.json",
     "aws-rolesanywhere-crl.json",
-    "aws-rolesanywhere-profile.json",
     "aws-rolesanywhere-trustanchor.json",
     "aws-route53-cidrcollection.json",
     "aws-route53-hostedzone.json",
     "aws-route53-recordset.json",
     "aws-route53-recordsetgroup.json",
     "aws-route53resolver-firewalldomainlist.json",
+    "aws-route53resolver-firewallrulegroup.json",
     "aws-route53resolver-firewallrulegroupassociation.json",
     "aws-route53resolver-resolverconfig.json",
     "aws-route53resolver-resolverdnssecconfig.json",
@@ -1223,6 +1242,7 @@ cached: list[str] = [
     "aws-servicediscovery-instance.json",
     "aws-servicediscovery-privatednsnamespace.json",
     "aws-servicediscovery-publicdnsnamespace.json",
+    "aws-servicediscovery-service.json",
     "aws-sns-subscription.json",
     "aws-sns-topic.json",
     "aws-sns-topicinlinepolicy.json",
