@@ -156,6 +156,7 @@ types: list[str] = [
     "AWS::CE::CostCategory",
     "AWS::Cassandra::Keyspace",
     "AWS::Cassandra::Table",
+    "AWS::Cassandra::Type",
     "AWS::CertificateManager::Account",
     "AWS::CertificateManager::Certificate",
     "AWS::Chatbot::CustomAction",
@@ -189,6 +190,7 @@ types: list[str] = [
     "AWS::CloudFormation::TypeActivation",
     "AWS::CloudFormation::WaitCondition",
     "AWS::CloudFormation::WaitConditionHandle",
+    "AWS::CloudFront::AnycastIpList",
     "AWS::CloudFront::CachePolicy",
     "AWS::CloudFront::CloudFrontOriginAccessIdentity",
     "AWS::CloudFront::ContinuousDeploymentPolicy",
@@ -239,6 +241,7 @@ types: list[str] = [
     "AWS::Cognito::IdentityPoolPrincipalTag",
     "AWS::Cognito::IdentityPoolRoleAttachment",
     "AWS::Cognito::LogDeliveryConfiguration",
+    "AWS::Cognito::ManagedLoginBranding",
     "AWS::Cognito::UserPool",
     "AWS::Cognito::UserPoolClient",
     "AWS::Cognito::UserPoolDomain",
@@ -631,15 +634,14 @@ types: list[str] = [
     "AWS::InspectorV2::CisScanConfiguration",
     "AWS::InspectorV2::Filter",
     "AWS::InternetMonitor::Monitor",
-    "AWS::IoT1Click::Device",
-    "AWS::IoT1Click::Placement",
-    "AWS::IoT1Click::Project",
+    "AWS::Invoicing::InvoiceUnit",
     "AWS::IoT::AccountAuditConfiguration",
     "AWS::IoT::Authorizer",
     "AWS::IoT::BillingGroup",
     "AWS::IoT::CACertificate",
     "AWS::IoT::Certificate",
     "AWS::IoT::CertificateProvider",
+    "AWS::IoT::Command",
     "AWS::IoT::CustomMetric",
     "AWS::IoT::Dimension",
     "AWS::IoT::DomainConfiguration",
@@ -734,6 +736,7 @@ types: list[str] = [
     "AWS::Logs::DeliveryDestination",
     "AWS::Logs::DeliverySource",
     "AWS::Logs::Destination",
+    "AWS::Logs::Integration",
     "AWS::Logs::LogAnomalyDetector",
     "AWS::Logs::LogGroup",
     "AWS::Logs::LogStream",
@@ -741,7 +744,9 @@ types: list[str] = [
     "AWS::Logs::QueryDefinition",
     "AWS::Logs::ResourcePolicy",
     "AWS::Logs::SubscriptionFilter",
+    "AWS::Logs::Transformer",
     "AWS::M2::Application",
+    "AWS::M2::Deployment",
     "AWS::M2::Environment",
     "AWS::MSK::BatchScramSecret",
     "AWS::MSK::Cluster",
@@ -796,6 +801,7 @@ types: list[str] = [
     "AWS::MediaStore::Container",
     "AWS::MemoryDB::ACL",
     "AWS::MemoryDB::Cluster",
+    "AWS::MemoryDB::MultiRegionCluster",
     "AWS::MemoryDB::ParameterGroup",
     "AWS::MemoryDB::SubnetGroup",
     "AWS::MemoryDB::User",
@@ -817,6 +823,7 @@ types: list[str] = [
     "AWS::NetworkManager::CoreNetwork",
     "AWS::NetworkManager::CustomerGatewayAssociation",
     "AWS::NetworkManager::Device",
+    "AWS::NetworkManager::DirectConnectGatewayAttachment",
     "AWS::NetworkManager::GlobalNetwork",
     "AWS::NetworkManager::Link",
     "AWS::NetworkManager::LinkAssociation",
@@ -892,6 +899,7 @@ types: list[str] = [
     "AWS::QLDB::Ledger",
     "AWS::QLDB::Stream",
     "AWS::QuickSight::Analysis",
+    "AWS::QuickSight::CustomPermissions",
     "AWS::QuickSight::Dashboard",
     "AWS::QuickSight::DataSet",
     "AWS::QuickSight::DataSource",
@@ -1049,6 +1057,7 @@ types: list[str] = [
     "AWS::SageMaker::MonitoringSchedule",
     "AWS::SageMaker::NotebookInstance",
     "AWS::SageMaker::NotebookInstanceLifecycleConfig",
+    "AWS::SageMaker::PartnerApp",
     "AWS::SageMaker::Pipeline",
     "AWS::SageMaker::Project",
     "AWS::SageMaker::Space",
@@ -1117,6 +1126,7 @@ types: list[str] = [
     "AWS::Synthetics::Canary",
     "AWS::Synthetics::Group",
     "AWS::SystemsManagerSAP::Application",
+    "AWS::Timestream::InfluxDBInstance",
     "AWS::Transfer::Agreement",
     "AWS::Transfer::Certificate",
     "AWS::Transfer::Connector",
@@ -1132,10 +1142,13 @@ types: list[str] = [
     "AWS::VpcLattice::AccessLogSubscription",
     "AWS::VpcLattice::AuthPolicy",
     "AWS::VpcLattice::Listener",
+    "AWS::VpcLattice::ResourceConfiguration",
+    "AWS::VpcLattice::ResourceGateway",
     "AWS::VpcLattice::ResourcePolicy",
     "AWS::VpcLattice::Rule",
     "AWS::VpcLattice::Service",
     "AWS::VpcLattice::ServiceNetwork",
+    "AWS::VpcLattice::ServiceNetworkResourceAssociation",
     "AWS::VpcLattice::ServiceNetworkServiceAssociation",
     "AWS::VpcLattice::ServiceNetworkVpcAssociation",
     "AWS::VpcLattice::TargetGroup",
@@ -1165,6 +1178,8 @@ types: list[str] = [
     "AWS::WAFv2::WebACLAssociation",
     "AWS::Wisdom::AIAgent",
     "AWS::Wisdom::AIAgentVersion",
+    "AWS::Wisdom::AIGuardrail",
+    "AWS::Wisdom::AIGuardrailVersion",
     "AWS::Wisdom::AIPrompt",
     "AWS::Wisdom::AIPromptVersion",
     "AWS::Wisdom::Assistant",
@@ -1246,7 +1261,6 @@ cached: list[str] = [
     "aws-apigatewayv2-vpclink.json",
     "aws-appconfig-application.json",
     "aws-appconfig-configurationprofile.json",
-    "aws-appconfig-deployment.json",
     "aws-appconfig-deploymentstrategy.json",
     "aws-appconfig-environment.json",
     "aws-appconfig-extension.json",
@@ -1341,6 +1355,7 @@ cached: list[str] = [
     "aws-budgets-budgetsaction.json",
     "aws-cassandra-keyspace.json",
     "aws-cassandra-table.json",
+    "aws-cassandra-type.json",
     "aws-ce-anomalymonitor.json",
     "aws-ce-anomalysubscription.json",
     "aws-ce-costcategory.json",
@@ -1377,6 +1392,7 @@ cached: list[str] = [
     "aws-cloudformation-typeactivation.json",
     "aws-cloudformation-waitcondition.json",
     "aws-cloudformation-waitconditionhandle.json",
+    "aws-cloudfront-anycastiplist.json",
     "aws-cloudfront-cachepolicy.json",
     "aws-cloudfront-cloudfrontoriginaccessidentity.json",
     "aws-cloudfront-continuousdeploymentpolicy.json",
@@ -1427,6 +1443,7 @@ cached: list[str] = [
     "aws-cognito-identitypoolprincipaltag.json",
     "aws-cognito-identitypoolroleattachment.json",
     "aws-cognito-logdeliveryconfiguration.json",
+    "aws-cognito-managedloginbranding.json",
     "aws-cognito-userpool.json",
     "aws-cognito-userpoolclient.json",
     "aws-cognito-userpooldomain.json",
@@ -1545,7 +1562,7 @@ cached: list[str] = [
     "aws-docdb-dbsubnetgroup.json",
     "aws-docdb-eventsubscription.json",
     "aws-docdbelastic-cluster.json",
-    "aws-dynamodb-globaltable.json",
+    "aws-dynamodb-table.json",
     "aws-ec2-capacityreservation.json",
     "aws-ec2-capacityreservationfleet.json",
     "aws-ec2-carriergateway.json",
@@ -1727,8 +1744,6 @@ cached: list[str] = [
     "aws-gamelift-gameservergroup.json",
     "aws-gamelift-gamesessionqueue.json",
     "aws-gamelift-location.json",
-    "aws-gamelift-matchmakingconfiguration.json",
-    "aws-gamelift-matchmakingruleset.json",
     "aws-gamelift-script.json",
     "aws-globalaccelerator-accelerator.json",
     "aws-globalaccelerator-crossaccountattachment.json",
@@ -1815,12 +1830,14 @@ cached: list[str] = [
     "aws-inspectorv2-cisscanconfiguration.json",
     "aws-inspectorv2-filter.json",
     "aws-internetmonitor-monitor.json",
+    "aws-invoicing-invoiceunit.json",
     "aws-iot-accountauditconfiguration.json",
     "aws-iot-authorizer.json",
     "aws-iot-billinggroup.json",
     "aws-iot-cacertificate.json",
     "aws-iot-certificate.json",
     "aws-iot-certificateprovider.json",
+    "aws-iot-command.json",
     "aws-iot-custommetric.json",
     "aws-iot-dimension.json",
     "aws-iot-domainconfiguration.json",
@@ -1843,14 +1860,10 @@ cached: list[str] = [
     "aws-iot-thingtype.json",
     "aws-iot-topicrule.json",
     "aws-iot-topicruledestination.json",
-    "aws-iot1click-device.json",
-    "aws-iot1click-placement.json",
-    "aws-iot1click-project.json",
     "aws-iotevents-alarmmodel.json",
     "aws-iotevents-detectormodel.json",
     "aws-iotevents-input.json",
     "aws-iotfleethub-application.json",
-    "aws-kafkaconnect-connector.json",
     "aws-kafkaconnect-customplugin.json",
     "aws-kafkaconnect-workerconfiguration.json",
     "aws-kendra-datasource.json",
@@ -1917,6 +1930,7 @@ cached: list[str] = [
     "aws-logs-deliverydestination.json",
     "aws-logs-deliverysource.json",
     "aws-logs-destination.json",
+    "aws-logs-integration.json",
     "aws-logs-loganomalydetector.json",
     "aws-logs-loggroup.json",
     "aws-logs-logstream.json",
@@ -1924,7 +1938,9 @@ cached: list[str] = [
     "aws-logs-querydefinition.json",
     "aws-logs-resourcepolicy.json",
     "aws-logs-subscriptionfilter.json",
+    "aws-logs-transformer.json",
     "aws-m2-application.json",
+    "aws-m2-deployment.json",
     "aws-m2-environment.json",
     "aws-macie-allowlist.json",
     "aws-macie-customdataidentifier.json",
@@ -1969,6 +1985,7 @@ cached: list[str] = [
     "aws-mediastore-container.json",
     "aws-memorydb-acl.json",
     "aws-memorydb-cluster.json",
+    "aws-memorydb-multiregioncluster.json",
     "aws-memorydb-parametergroup.json",
     "aws-memorydb-subnetgroup.json",
     "aws-memorydb-user.json",
@@ -1998,6 +2015,7 @@ cached: list[str] = [
     "aws-networkmanager-corenetwork.json",
     "aws-networkmanager-customergatewayassociation.json",
     "aws-networkmanager-device.json",
+    "aws-networkmanager-directconnectgatewayattachment.json",
     "aws-networkmanager-globalnetwork.json",
     "aws-networkmanager-link.json",
     "aws-networkmanager-linkassociation.json",
@@ -2036,6 +2054,7 @@ cached: list[str] = [
     "aws-organizations-account.json",
     "aws-organizations-organization.json",
     "aws-organizations-organizationalunit.json",
+    "aws-organizations-policy.json",
     "aws-organizations-resourcepolicy.json",
     "aws-osis-pipeline.json",
     "aws-pcaconnectorad-connector.json",
@@ -2067,6 +2086,8 @@ cached: list[str] = [
     "aws-qldb-ledger.json",
     "aws-qldb-stream.json",
     "aws-quicksight-analysis.json",
+    "aws-quicksight-custompermissions.json",
+    "aws-quicksight-dashboard.json",
     "aws-quicksight-dataset.json",
     "aws-quicksight-datasource.json",
     "aws-quicksight-folder.json",
@@ -2182,6 +2203,7 @@ cached: list[str] = [
     "aws-sagemaker-monitoringschedule.json",
     "aws-sagemaker-notebookinstance.json",
     "aws-sagemaker-notebookinstancelifecycleconfig.json",
+    "aws-sagemaker-partnerapp.json",
     "aws-sagemaker-pipeline.json",
     "aws-sagemaker-project.json",
     "aws-sagemaker-space.json",
@@ -2300,14 +2322,16 @@ cached: list[str] = [
     "aws-verifiedpermissions-policy.json",
     "aws-verifiedpermissions-policystore.json",
     "aws-verifiedpermissions-policytemplate.json",
-    "aws-voiceid-domain.json",
     "aws-vpclattice-accesslogsubscription.json",
     "aws-vpclattice-authpolicy.json",
     "aws-vpclattice-listener.json",
+    "aws-vpclattice-resourceconfiguration.json",
+    "aws-vpclattice-resourcegateway.json",
     "aws-vpclattice-resourcepolicy.json",
     "aws-vpclattice-rule.json",
     "aws-vpclattice-service.json",
     "aws-vpclattice-servicenetwork.json",
+    "aws-vpclattice-servicenetworkresourceassociation.json",
     "aws-vpclattice-servicenetworkserviceassociation.json",
     "aws-vpclattice-servicenetworkvpcassociation.json",
     "aws-vpclattice-targetgroup.json",
@@ -2335,9 +2359,9 @@ cached: list[str] = [
     "aws-wafv2-rulegroup.json",
     "aws-wafv2-webacl.json",
     "aws-wafv2-webaclassociation.json",
-    "aws-wisdom-aiagent.json",
     "aws-wisdom-aiagentversion.json",
-    "aws-wisdom-aiprompt.json",
+    "aws-wisdom-aiguardrail.json",
+    "aws-wisdom-aiguardrailversion.json",
     "aws-wisdom-aipromptversion.json",
     "aws-wisdom-assistant.json",
     "aws-wisdom-assistantassociation.json",
@@ -2346,6 +2370,7 @@ cached: list[str] = [
     "aws-wisdom-messagetemplateversion.json",
     "aws-workspaces-connectionalias.json",
     "aws-workspaces-workspace.json",
+    "aws-workspaces-workspacespool.json",
     "aws-workspacesthinclient-environment.json",
     "aws-workspacesweb-browsersettings.json",
     "aws-workspacesweb-dataprotectionsettings.json",
