@@ -143,6 +143,7 @@ types: list[str] = [
     "AWS::CE::CostCategory",
     "AWS::Cassandra::Keyspace",
     "AWS::Cassandra::Table",
+    "AWS::Cassandra::Type",
     "AWS::CertificateManager::Account",
     "AWS::CertificateManager::Certificate",
     "AWS::Chatbot::CustomAction",
@@ -167,6 +168,7 @@ types: list[str] = [
     "AWS::CloudFormation::TypeActivation",
     "AWS::CloudFormation::WaitCondition",
     "AWS::CloudFormation::WaitConditionHandle",
+    "AWS::CloudFront::AnycastIpList",
     "AWS::CloudFront::CachePolicy",
     "AWS::CloudFront::CloudFrontOriginAccessIdentity",
     "AWS::CloudFront::ContinuousDeploymentPolicy",
@@ -754,6 +756,7 @@ types: list[str] = [
     "AWS::PCAConnectorSCEP::Connector",
     "AWS::Pipes::Pipe",
     "AWS::QuickSight::Analysis",
+    "AWS::QuickSight::CustomPermissions",
     "AWS::QuickSight::Dashboard",
     "AWS::QuickSight::DataSet",
     "AWS::QuickSight::DataSource",
@@ -908,6 +911,7 @@ types: list[str] = [
     "AWS::SageMaker::MonitoringSchedule",
     "AWS::SageMaker::NotebookInstance",
     "AWS::SageMaker::NotebookInstanceLifecycleConfig",
+    "AWS::SageMaker::PartnerApp",
     "AWS::SageMaker::Pipeline",
     "AWS::SageMaker::Project",
     "AWS::SageMaker::Space",
@@ -1059,6 +1063,7 @@ cached: list[str] = [
     "aws-apigateway-documentationversion.json",
     "aws-apigateway-domainname.json",
     "aws-apigateway-domainnameaccessassociation.json",
+    "aws-apigateway-domainnamev2.json",
     "aws-apigateway-gatewayresponse.json",
     "aws-apigateway-method.json",
     "aws-apigateway-model.json",
@@ -1143,7 +1148,6 @@ cached: list[str] = [
     "aws-backup-backupselection.json",
     "aws-backup-backupvault.json",
     "aws-backup-framework.json",
-    "aws-backup-logicallyairgappedbackupvault.json",
     "aws-backup-reportplan.json",
     "aws-backup-restoretestingplan.json",
     "aws-backup-restoretestingselection.json",
@@ -1168,6 +1172,7 @@ cached: list[str] = [
     "aws-budgets-budgetsaction.json",
     "aws-cassandra-keyspace.json",
     "aws-cassandra-table.json",
+    "aws-cassandra-type.json",
     "aws-ce-anomalymonitor.json",
     "aws-ce-anomalysubscription.json",
     "aws-ce-costcategory.json",
@@ -1195,6 +1200,7 @@ cached: list[str] = [
     "aws-cloudformation-typeactivation.json",
     "aws-cloudformation-waitcondition.json",
     "aws-cloudformation-waitconditionhandle.json",
+    "aws-cloudfront-anycastiplist.json",
     "aws-cloudfront-cachepolicy.json",
     "aws-cloudfront-cloudfrontoriginaccessidentity.json",
     "aws-cloudfront-continuousdeploymentpolicy.json",
@@ -1322,7 +1328,6 @@ cached: list[str] = [
     "aws-docdb-dbsubnetgroup.json",
     "aws-docdb-eventsubscription.json",
     "aws-docdbelastic-cluster.json",
-    "aws-dynamodb-globaltable.json",
     "aws-dynamodb-table.json",
     "aws-ec2-capacityreservation.json",
     "aws-ec2-capacityreservationfleet.json",
@@ -1498,8 +1503,6 @@ cached: list[str] = [
     "aws-gamelift-gameservergroup.json",
     "aws-gamelift-gamesessionqueue.json",
     "aws-gamelift-location.json",
-    "aws-gamelift-matchmakingconfiguration.json",
-    "aws-gamelift-matchmakingruleset.json",
     "aws-gamelift-script.json",
     "aws-globalaccelerator-accelerator.json",
     "aws-globalaccelerator-crossaccountattachment.json",
@@ -1640,6 +1643,7 @@ cached: list[str] = [
     "aws-location-routecalculator.json",
     "aws-location-tracker.json",
     "aws-location-trackerconsumer.json",
+    "aws-logs-accountpolicy.json",
     "aws-logs-delivery.json",
     "aws-logs-deliverydestination.json",
     "aws-logs-deliverysource.json",
@@ -1655,6 +1659,7 @@ cached: list[str] = [
     "aws-logs-transformer.json",
     "aws-m2-application.json",
     "aws-m2-deployment.json",
+    "aws-m2-environment.json",
     "aws-macie-allowlist.json",
     "aws-macie-customdataidentifier.json",
     "aws-macie-findingsfilter.json",
@@ -1760,6 +1765,7 @@ cached: list[str] = [
     "aws-pcaconnectorscep-connector.json",
     "aws-pipes-pipe.json",
     "aws-quicksight-analysis.json",
+    "aws-quicksight-custompermissions.json",
     "aws-quicksight-dashboard.json",
     "aws-quicksight-dataset.json",
     "aws-quicksight-datasource.json",
@@ -1873,6 +1879,7 @@ cached: list[str] = [
     "aws-sagemaker-monitoringschedule.json",
     "aws-sagemaker-notebookinstance.json",
     "aws-sagemaker-notebookinstancelifecycleconfig.json",
+    "aws-sagemaker-partnerapp.json",
     "aws-sagemaker-pipeline.json",
     "aws-sagemaker-project.json",
     "aws-sagemaker-space.json",
@@ -1925,6 +1932,7 @@ cached: list[str] = [
     "aws-servicediscovery-instance.json",
     "aws-servicediscovery-privatednsnamespace.json",
     "aws-servicediscovery-publicdnsnamespace.json",
+    "aws-servicediscovery-service.json",
     "aws-ses-configurationset.json",
     "aws-ses-configurationseteventdestination.json",
     "aws-ses-contactlist.json",
