@@ -168,6 +168,7 @@ types: list[str] = [
     "AWS::CUR::ReportDefinition",
     "AWS::Cassandra::Keyspace",
     "AWS::Cassandra::Table",
+    "AWS::Cassandra::Type",
     "AWS::CertificateManager::Account",
     "AWS::CertificateManager::Certificate",
     "AWS::Chatbot::CustomAction",
@@ -201,6 +202,7 @@ types: list[str] = [
     "AWS::CloudFormation::TypeActivation",
     "AWS::CloudFormation::WaitCondition",
     "AWS::CloudFormation::WaitConditionHandle",
+    "AWS::CloudFront::AnycastIpList",
     "AWS::CloudFront::CachePolicy",
     "AWS::CloudFront::CloudFrontOriginAccessIdentity",
     "AWS::CloudFront::ContinuousDeploymentPolicy",
@@ -252,6 +254,7 @@ types: list[str] = [
     "AWS::Cognito::IdentityPoolPrincipalTag",
     "AWS::Cognito::IdentityPoolRoleAttachment",
     "AWS::Cognito::LogDeliveryConfiguration",
+    "AWS::Cognito::ManagedLoginBranding",
     "AWS::Cognito::UserPool",
     "AWS::Cognito::UserPoolClient",
     "AWS::Cognito::UserPoolDomain",
@@ -688,15 +691,14 @@ types: list[str] = [
     "AWS::InspectorV2::CisScanConfiguration",
     "AWS::InspectorV2::Filter",
     "AWS::InternetMonitor::Monitor",
-    "AWS::IoT1Click::Device",
-    "AWS::IoT1Click::Placement",
-    "AWS::IoT1Click::Project",
+    "AWS::Invoicing::InvoiceUnit",
     "AWS::IoT::AccountAuditConfiguration",
     "AWS::IoT::Authorizer",
     "AWS::IoT::BillingGroup",
     "AWS::IoT::CACertificate",
     "AWS::IoT::Certificate",
     "AWS::IoT::CertificateProvider",
+    "AWS::IoT::Command",
     "AWS::IoT::CustomMetric",
     "AWS::IoT::Dimension",
     "AWS::IoT::DomainConfiguration",
@@ -829,6 +831,7 @@ types: list[str] = [
     "AWS::Logs::DeliveryDestination",
     "AWS::Logs::DeliverySource",
     "AWS::Logs::Destination",
+    "AWS::Logs::Integration",
     "AWS::Logs::LogAnomalyDetector",
     "AWS::Logs::LogGroup",
     "AWS::Logs::LogStream",
@@ -836,6 +839,7 @@ types: list[str] = [
     "AWS::Logs::QueryDefinition",
     "AWS::Logs::ResourcePolicy",
     "AWS::Logs::SubscriptionFilter",
+    "AWS::Logs::Transformer",
     "AWS::LookoutEquipment::InferenceScheduler",
     "AWS::LookoutMetrics::Alert",
     "AWS::LookoutMetrics::AnomalyDetector",
@@ -903,6 +907,7 @@ types: list[str] = [
     "AWS::MediaTailor::VodSource",
     "AWS::MemoryDB::ACL",
     "AWS::MemoryDB::Cluster",
+    "AWS::MemoryDB::MultiRegionCluster",
     "AWS::MemoryDB::ParameterGroup",
     "AWS::MemoryDB::SubnetGroup",
     "AWS::MemoryDB::User",
@@ -924,6 +929,7 @@ types: list[str] = [
     "AWS::NetworkManager::CoreNetwork",
     "AWS::NetworkManager::CustomerGatewayAssociation",
     "AWS::NetworkManager::Device",
+    "AWS::NetworkManager::DirectConnectGatewayAttachment",
     "AWS::NetworkManager::GlobalNetwork",
     "AWS::NetworkManager::Link",
     "AWS::NetworkManager::LinkAssociation",
@@ -974,6 +980,9 @@ types: list[str] = [
     "AWS::PCAConnectorAD::TemplateGroupAccessControlEntry",
     "AWS::PCAConnectorSCEP::Challenge",
     "AWS::PCAConnectorSCEP::Connector",
+    "AWS::PCS::Cluster",
+    "AWS::PCS::ComputeNodeGroup",
+    "AWS::PCS::Queue",
     "AWS::Panorama::ApplicationInstance",
     "AWS::Panorama::Package",
     "AWS::Panorama::PackageVersion",
@@ -1011,14 +1020,17 @@ types: list[str] = [
     "AWS::Proton::EnvironmentTemplate",
     "AWS::Proton::ServiceTemplate",
     "AWS::QBusiness::Application",
+    "AWS::QBusiness::DataAccessor",
     "AWS::QBusiness::DataSource",
     "AWS::QBusiness::Index",
+    "AWS::QBusiness::Permission",
     "AWS::QBusiness::Plugin",
     "AWS::QBusiness::Retriever",
     "AWS::QBusiness::WebExperience",
     "AWS::QLDB::Ledger",
     "AWS::QLDB::Stream",
     "AWS::QuickSight::Analysis",
+    "AWS::QuickSight::CustomPermissions",
     "AWS::QuickSight::Dashboard",
     "AWS::QuickSight::DataSet",
     "AWS::QuickSight::DataSource",
@@ -1130,6 +1142,8 @@ types: list[str] = [
     "AWS::S3Outposts::Bucket",
     "AWS::S3Outposts::BucketPolicy",
     "AWS::S3Outposts::Endpoint",
+    "AWS::S3Tables::TableBucket",
+    "AWS::S3Tables::TableBucketPolicy",
     "AWS::SDB::Domain",
     "AWS::SES::ConfigurationSet",
     "AWS::SES::ConfigurationSetEventDestination",
@@ -1203,6 +1217,7 @@ types: list[str] = [
     "AWS::SageMaker::MonitoringSchedule",
     "AWS::SageMaker::NotebookInstance",
     "AWS::SageMaker::NotebookInstanceLifecycleConfig",
+    "AWS::SageMaker::PartnerApp",
     "AWS::SageMaker::Pipeline",
     "AWS::SageMaker::Project",
     "AWS::SageMaker::Space",
@@ -1291,10 +1306,13 @@ types: list[str] = [
     "AWS::VpcLattice::AccessLogSubscription",
     "AWS::VpcLattice::AuthPolicy",
     "AWS::VpcLattice::Listener",
+    "AWS::VpcLattice::ResourceConfiguration",
+    "AWS::VpcLattice::ResourceGateway",
     "AWS::VpcLattice::ResourcePolicy",
     "AWS::VpcLattice::Rule",
     "AWS::VpcLattice::Service",
     "AWS::VpcLattice::ServiceNetwork",
+    "AWS::VpcLattice::ServiceNetworkResourceAssociation",
     "AWS::VpcLattice::ServiceNetworkServiceAssociation",
     "AWS::VpcLattice::ServiceNetworkVpcAssociation",
     "AWS::VpcLattice::TargetGroup",
@@ -1324,6 +1342,8 @@ types: list[str] = [
     "AWS::WAFv2::WebACLAssociation",
     "AWS::Wisdom::AIAgent",
     "AWS::Wisdom::AIAgentVersion",
+    "AWS::Wisdom::AIGuardrail",
+    "AWS::Wisdom::AIGuardrailVersion",
     "AWS::Wisdom::AIPrompt",
     "AWS::Wisdom::AIPromptVersion",
     "AWS::Wisdom::Assistant",
