@@ -138,12 +138,16 @@ types: list[str] = [
     "AWS::Batch::JobDefinition",
     "AWS::Batch::JobQueue",
     "AWS::Batch::SchedulingPolicy",
+    "AWS::Bedrock::Agent",
+    "AWS::Bedrock::AgentAlias",
     "AWS::Bedrock::ApplicationInferenceProfile",
+    "AWS::Bedrock::DataSource",
     "AWS::Bedrock::Flow",
     "AWS::Bedrock::FlowAlias",
     "AWS::Bedrock::FlowVersion",
     "AWS::Bedrock::Guardrail",
     "AWS::Bedrock::GuardrailVersion",
+    "AWS::Bedrock::KnowledgeBase",
     "AWS::Bedrock::Prompt",
     "AWS::Bedrock::PromptVersion",
     "AWS::Budgets::Budget",
@@ -154,6 +158,7 @@ types: list[str] = [
     "AWS::CE::CostCategory",
     "AWS::Cassandra::Keyspace",
     "AWS::Cassandra::Table",
+    "AWS::Cassandra::Type",
     "AWS::CertificateManager::Account",
     "AWS::CertificateManager::Certificate",
     "AWS::Chatbot::CustomAction",
@@ -187,6 +192,7 @@ types: list[str] = [
     "AWS::CloudFormation::TypeActivation",
     "AWS::CloudFormation::WaitCondition",
     "AWS::CloudFormation::WaitConditionHandle",
+    "AWS::CloudFront::AnycastIpList",
     "AWS::CloudFront::CachePolicy",
     "AWS::CloudFront::CloudFrontOriginAccessIdentity",
     "AWS::CloudFront::ContinuousDeploymentPolicy",
@@ -625,15 +631,14 @@ types: list[str] = [
     "AWS::InspectorV2::CisScanConfiguration",
     "AWS::InspectorV2::Filter",
     "AWS::InternetMonitor::Monitor",
-    "AWS::IoT1Click::Device",
-    "AWS::IoT1Click::Placement",
-    "AWS::IoT1Click::Project",
+    "AWS::Invoicing::InvoiceUnit",
     "AWS::IoT::AccountAuditConfiguration",
     "AWS::IoT::Authorizer",
     "AWS::IoT::BillingGroup",
     "AWS::IoT::CACertificate",
     "AWS::IoT::Certificate",
     "AWS::IoT::CertificateProvider",
+    "AWS::IoT::Command",
     "AWS::IoT::CustomMetric",
     "AWS::IoT::Dimension",
     "AWS::IoT::DomainConfiguration",
@@ -736,6 +741,7 @@ types: list[str] = [
     "AWS::Logs::DeliveryDestination",
     "AWS::Logs::DeliverySource",
     "AWS::Logs::Destination",
+    "AWS::Logs::Integration",
     "AWS::Logs::LogAnomalyDetector",
     "AWS::Logs::LogGroup",
     "AWS::Logs::LogStream",
@@ -743,10 +749,12 @@ types: list[str] = [
     "AWS::Logs::QueryDefinition",
     "AWS::Logs::ResourcePolicy",
     "AWS::Logs::SubscriptionFilter",
+    "AWS::Logs::Transformer",
     "AWS::LookoutMetrics::Alert",
     "AWS::LookoutMetrics::AnomalyDetector",
     "AWS::LookoutVision::Project",
     "AWS::M2::Application",
+    "AWS::M2::Deployment",
     "AWS::M2::Environment",
     "AWS::MSK::BatchScramSecret",
     "AWS::MSK::Cluster",
@@ -804,6 +812,7 @@ types: list[str] = [
     "AWS::MediaTailor::VodSource",
     "AWS::MemoryDB::ACL",
     "AWS::MemoryDB::Cluster",
+    "AWS::MemoryDB::MultiRegionCluster",
     "AWS::MemoryDB::ParameterGroup",
     "AWS::MemoryDB::SubnetGroup",
     "AWS::MemoryDB::User",
@@ -825,6 +834,7 @@ types: list[str] = [
     "AWS::NetworkManager::CoreNetwork",
     "AWS::NetworkManager::CustomerGatewayAssociation",
     "AWS::NetworkManager::Device",
+    "AWS::NetworkManager::DirectConnectGatewayAttachment",
     "AWS::NetworkManager::GlobalNetwork",
     "AWS::NetworkManager::Link",
     "AWS::NetworkManager::LinkAssociation",
@@ -866,6 +876,9 @@ types: list[str] = [
     "AWS::PCAConnectorAD::TemplateGroupAccessControlEntry",
     "AWS::PCAConnectorSCEP::Challenge",
     "AWS::PCAConnectorSCEP::Connector",
+    "AWS::PCS::Cluster",
+    "AWS::PCS::ComputeNodeGroup",
+    "AWS::PCS::Queue",
     "AWS::PaymentCryptography::Alias",
     "AWS::PaymentCryptography::Key",
     "AWS::Personalize::Dataset",
@@ -880,6 +893,7 @@ types: list[str] = [
     "AWS::QLDB::Ledger",
     "AWS::QLDB::Stream",
     "AWS::QuickSight::Analysis",
+    "AWS::QuickSight::CustomPermissions",
     "AWS::QuickSight::Dashboard",
     "AWS::QuickSight::DataSet",
     "AWS::QuickSight::DataSource",
@@ -983,6 +997,8 @@ types: list[str] = [
     "AWS::S3Outposts::Bucket",
     "AWS::S3Outposts::BucketPolicy",
     "AWS::S3Outposts::Endpoint",
+    "AWS::S3Tables::TableBucket",
+    "AWS::S3Tables::TableBucketPolicy",
     "AWS::SDB::Domain",
     "AWS::SES::ConfigurationSet",
     "AWS::SES::ConfigurationSetEventDestination",
@@ -1049,6 +1065,7 @@ types: list[str] = [
     "AWS::SageMaker::MonitoringSchedule",
     "AWS::SageMaker::NotebookInstance",
     "AWS::SageMaker::NotebookInstanceLifecycleConfig",
+    "AWS::SageMaker::PartnerApp",
     "AWS::SageMaker::Pipeline",
     "AWS::SageMaker::Project",
     "AWS::SageMaker::Space",
@@ -1136,10 +1153,13 @@ types: list[str] = [
     "AWS::VpcLattice::AccessLogSubscription",
     "AWS::VpcLattice::AuthPolicy",
     "AWS::VpcLattice::Listener",
+    "AWS::VpcLattice::ResourceConfiguration",
+    "AWS::VpcLattice::ResourceGateway",
     "AWS::VpcLattice::ResourcePolicy",
     "AWS::VpcLattice::Rule",
     "AWS::VpcLattice::Service",
     "AWS::VpcLattice::ServiceNetwork",
+    "AWS::VpcLattice::ServiceNetworkResourceAssociation",
     "AWS::VpcLattice::ServiceNetworkServiceAssociation",
     "AWS::VpcLattice::ServiceNetworkVpcAssociation",
     "AWS::VpcLattice::TargetGroup",
@@ -1230,7 +1250,6 @@ cached: list[str] = [
     "aws-apigatewayv2-vpclink.json",
     "aws-appconfig-application.json",
     "aws-appconfig-configurationprofile.json",
-    "aws-appconfig-deployment.json",
     "aws-appconfig-deploymentstrategy.json",
     "aws-appconfig-environment.json",
     "aws-appconfig-extension.json",
@@ -1312,18 +1331,23 @@ cached: list[str] = [
     "aws-batch-jobdefinition.json",
     "aws-batch-jobqueue.json",
     "aws-batch-schedulingpolicy.json",
+    "aws-bedrock-agent.json",
+    "aws-bedrock-agentalias.json",
     "aws-bedrock-applicationinferenceprofile.json",
+    "aws-bedrock-datasource.json",
     "aws-bedrock-flow.json",
     "aws-bedrock-flowalias.json",
     "aws-bedrock-flowversion.json",
     "aws-bedrock-guardrail.json",
     "aws-bedrock-guardrailversion.json",
+    "aws-bedrock-knowledgebase.json",
     "aws-bedrock-prompt.json",
     "aws-bedrock-promptversion.json",
     "aws-budgets-budget.json",
     "aws-budgets-budgetsaction.json",
     "aws-cassandra-keyspace.json",
     "aws-cassandra-table.json",
+    "aws-cassandra-type.json",
     "aws-ce-anomalymonitor.json",
     "aws-ce-anomalysubscription.json",
     "aws-ce-costcategory.json",
@@ -1360,6 +1384,7 @@ cached: list[str] = [
     "aws-cloudformation-typeactivation.json",
     "aws-cloudformation-waitcondition.json",
     "aws-cloudformation-waitconditionhandle.json",
+    "aws-cloudfront-anycastiplist.json",
     "aws-cloudfront-cachepolicy.json",
     "aws-cloudfront-cloudfrontoriginaccessidentity.json",
     "aws-cloudfront-continuousdeploymentpolicy.json",
@@ -1411,6 +1436,7 @@ cached: list[str] = [
     "aws-cognito-identitypoolprincipaltag.json",
     "aws-cognito-identitypoolroleattachment.json",
     "aws-cognito-logdeliveryconfiguration.json",
+    "aws-cognito-managedloginbranding.json",
     "aws-cognito-userpool.json",
     "aws-cognito-userpoolclient.json",
     "aws-cognito-userpooldomain.json",
@@ -1504,7 +1530,7 @@ cached: list[str] = [
     "aws-docdb-dbsubnetgroup.json",
     "aws-docdb-eventsubscription.json",
     "aws-docdbelastic-cluster.json",
-    "aws-dynamodb-globaltable.json",
+    "aws-dynamodb-table.json",
     "aws-ec2-capacityreservation.json",
     "aws-ec2-capacityreservationfleet.json",
     "aws-ec2-carriergateway.json",
@@ -1629,6 +1655,7 @@ cached: list[str] = [
     "aws-elasticache-replicationgroup.json",
     "aws-elasticache-securitygroup.json",
     "aws-elasticache-securitygroupingress.json",
+    "aws-elasticache-serverlesscache.json",
     "aws-elasticache-subnetgroup.json",
     "aws-elasticache-user.json",
     "aws-elasticbeanstalk-application.json",
@@ -1661,6 +1688,7 @@ cached: list[str] = [
     "aws-entityresolution-schemamapping.json",
     "aws-events-apidestination.json",
     "aws-events-archive.json",
+    "aws-events-connection.json",
     "aws-events-endpoint.json",
     "aws-events-eventbus.json",
     "aws-events-eventbuspolicy.json",
@@ -1700,8 +1728,6 @@ cached: list[str] = [
     "aws-gamelift-gameservergroup.json",
     "aws-gamelift-gamesessionqueue.json",
     "aws-gamelift-location.json",
-    "aws-gamelift-matchmakingconfiguration.json",
-    "aws-gamelift-matchmakingruleset.json",
     "aws-gamelift-script.json",
     "aws-globalaccelerator-accelerator.json",
     "aws-globalaccelerator-crossaccountattachment.json",
@@ -1791,12 +1817,14 @@ cached: list[str] = [
     "aws-inspectorv2-cisscanconfiguration.json",
     "aws-inspectorv2-filter.json",
     "aws-internetmonitor-monitor.json",
+    "aws-invoicing-invoiceunit.json",
     "aws-iot-accountauditconfiguration.json",
     "aws-iot-authorizer.json",
     "aws-iot-billinggroup.json",
     "aws-iot-cacertificate.json",
     "aws-iot-certificate.json",
     "aws-iot-certificateprovider.json",
+    "aws-iot-command.json",
     "aws-iot-custommetric.json",
     "aws-iot-dimension.json",
     "aws-iot-domainconfiguration.json",
@@ -1819,9 +1847,6 @@ cached: list[str] = [
     "aws-iot-thingtype.json",
     "aws-iot-topicrule.json",
     "aws-iot-topicruledestination.json",
-    "aws-iot1click-device.json",
-    "aws-iot1click-placement.json",
-    "aws-iot1click-project.json",
     "aws-iotanalytics-channel.json",
     "aws-iotanalytics-dataset.json",
     "aws-iotanalytics-datastore.json",
@@ -1830,6 +1855,7 @@ cached: list[str] = [
     "aws-iotevents-detectormodel.json",
     "aws-iotevents-input.json",
     "aws-iotfleethub-application.json",
+    "aws-iotsitewise-accesspolicy.json",
     "aws-iotsitewise-asset.json",
     "aws-iotsitewise-assetmodel.json",
     "aws-iotsitewise-dashboard.json",
@@ -1899,6 +1925,7 @@ cached: list[str] = [
     "aws-logs-deliverydestination.json",
     "aws-logs-deliverysource.json",
     "aws-logs-destination.json",
+    "aws-logs-integration.json",
     "aws-logs-loganomalydetector.json",
     "aws-logs-loggroup.json",
     "aws-logs-logstream.json",
@@ -1906,11 +1933,12 @@ cached: list[str] = [
     "aws-logs-querydefinition.json",
     "aws-logs-resourcepolicy.json",
     "aws-logs-subscriptionfilter.json",
+    "aws-logs-transformer.json",
     "aws-lookoutmetrics-alert.json",
     "aws-lookoutmetrics-anomalydetector.json",
     "aws-lookoutvision-project.json",
     "aws-m2-application.json",
-    "aws-m2-environment.json",
+    "aws-m2-deployment.json",
     "aws-macie-allowlist.json",
     "aws-macie-customdataidentifier.json",
     "aws-macie-findingsfilter.json",
@@ -1957,6 +1985,7 @@ cached: list[str] = [
     "aws-mediatailor-vodsource.json",
     "aws-memorydb-acl.json",
     "aws-memorydb-cluster.json",
+    "aws-memorydb-multiregioncluster.json",
     "aws-memorydb-parametergroup.json",
     "aws-memorydb-subnetgroup.json",
     "aws-memorydb-user.json",
@@ -1986,6 +2015,7 @@ cached: list[str] = [
     "aws-networkmanager-corenetwork.json",
     "aws-networkmanager-customergatewayassociation.json",
     "aws-networkmanager-device.json",
+    "aws-networkmanager-directconnectgatewayattachment.json",
     "aws-networkmanager-globalnetwork.json",
     "aws-networkmanager-link.json",
     "aws-networkmanager-linkassociation.json",
@@ -2016,6 +2046,7 @@ cached: list[str] = [
     "aws-organizations-account.json",
     "aws-organizations-organization.json",
     "aws-organizations-organizationalunit.json",
+    "aws-organizations-policy.json",
     "aws-organizations-resourcepolicy.json",
     "aws-osis-pipeline.json",
     "aws-paymentcryptography-alias.json",
@@ -2027,6 +2058,9 @@ cached: list[str] = [
     "aws-pcaconnectorad-templategroupaccesscontrolentry.json",
     "aws-pcaconnectorscep-challenge.json",
     "aws-pcaconnectorscep-connector.json",
+    "aws-pcs-cluster.json",
+    "aws-pcs-computenodegroup.json",
+    "aws-pcs-queue.json",
     "aws-personalize-dataset.json",
     "aws-personalize-datasetgroup.json",
     "aws-personalize-schema.json",
@@ -2039,6 +2073,7 @@ cached: list[str] = [
     "aws-qldb-ledger.json",
     "aws-qldb-stream.json",
     "aws-quicksight-analysis.json",
+    "aws-quicksight-custompermissions.json",
     "aws-quicksight-dashboard.json",
     "aws-quicksight-dataset.json",
     "aws-quicksight-datasource.json",
@@ -2080,6 +2115,7 @@ cached: list[str] = [
     "aws-redshiftserverless-namespace.json",
     "aws-redshiftserverless-workgroup.json",
     "aws-refactorspaces-application.json",
+    "aws-refactorspaces-environment.json",
     "aws-refactorspaces-route.json",
     "aws-refactorspaces-service.json",
     "aws-rekognition-collection.json",
@@ -2141,8 +2177,11 @@ cached: list[str] = [
     "aws-s3outposts-bucket.json",
     "aws-s3outposts-bucketpolicy.json",
     "aws-s3outposts-endpoint.json",
+    "aws-s3tables-tablebucket.json",
+    "aws-s3tables-tablebucketpolicy.json",
     "aws-sagemaker-app.json",
     "aws-sagemaker-appimageconfig.json",
+    "aws-sagemaker-cluster.json",
     "aws-sagemaker-coderepository.json",
     "aws-sagemaker-dataqualityjobdefinition.json",
     "aws-sagemaker-device.json",
@@ -2165,6 +2204,7 @@ cached: list[str] = [
     "aws-sagemaker-monitoringschedule.json",
     "aws-sagemaker-notebookinstance.json",
     "aws-sagemaker-notebookinstancelifecycleconfig.json",
+    "aws-sagemaker-partnerapp.json",
     "aws-sagemaker-pipeline.json",
     "aws-sagemaker-project.json",
     "aws-sagemaker-space.json",
@@ -2291,10 +2331,13 @@ cached: list[str] = [
     "aws-vpclattice-accesslogsubscription.json",
     "aws-vpclattice-authpolicy.json",
     "aws-vpclattice-listener.json",
+    "aws-vpclattice-resourceconfiguration.json",
+    "aws-vpclattice-resourcegateway.json",
     "aws-vpclattice-resourcepolicy.json",
     "aws-vpclattice-rule.json",
     "aws-vpclattice-service.json",
     "aws-vpclattice-servicenetwork.json",
+    "aws-vpclattice-servicenetworkresourceassociation.json",
     "aws-vpclattice-servicenetworkserviceassociation.json",
     "aws-vpclattice-servicenetworkvpcassociation.json",
     "aws-vpclattice-targetgroup.json",
